@@ -4,7 +4,7 @@ from __future__ import annotations
 
 import logging
 import time
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 from ..device_capabilities import filter_plm_inputs, get_device_inputs
 
@@ -848,3 +848,47 @@ class PlayerProperties:
             outputs.append(f"BT: {device['name']}")
 
         return outputs
+
+    # === UPnP Health ===
+
+    @property
+    def upnp_health_status(self) -> dict[str, Any] | None:
+        """UPnP event health statistics.
+
+        Returns health tracking information if UPnP is enabled, None otherwise.
+
+        Returns:
+            Dictionary with health statistics:
+            - is_healthy: bool - Whether UPnP events are working properly
+            - miss_rate: float - Fraction of changes missed (0.0-1.0)
+            - detected_changes: int - Total changes detected by polling
+            - missed_changes: int - Changes polling saw but UPnP didn't
+            - has_enough_samples: bool - Whether enough data for reliable health assessment
+
+            None if UPnP is not enabled or health tracker not available.
+        """
+        if not self.player._upnp_health_tracker:
+            return None
+        return self.player._upnp_health_tracker.statistics
+
+    @property
+    def upnp_is_healthy(self) -> bool | None:
+        """Whether UPnP events are working properly.
+
+        Returns:
+            True if UPnP is healthy, False if degraded/failed, None if UPnP not enabled.
+        """
+        if not self.player._upnp_health_tracker:
+            return None
+        return self.player._upnp_health_tracker.is_healthy
+
+    @property
+    def upnp_miss_rate(self) -> float | None:
+        """UPnP event miss rate (0.0 = perfect, 1.0 = all missed).
+
+        Returns:
+            Fraction of changes missed by UPnP (0.0 to 1.0), or None if UPnP not enabled.
+        """
+        if not self.player._upnp_health_tracker:
+            return None
+        return self.player._upnp_health_tracker.miss_rate
